JsonMapper class

Constructors

JsonMapper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

verbose ↔ bool
getter/setter pair

Static Methods

deserialize<T>(dynamic jsonVal, [String? typeName]) → T?
deserializeFromMap<T>(dynamic jsonVal, [String? typeName]) → T?
isConverterRegistered<T>() → bool
isMapperRegistered<T>() → bool
register<T>(JsonObjectMapper<T> mapper) → void
registerConverter<TFrom, TTo>(JsonConverter<TFrom, TTo> transformer) → void
registerListCast<T>(ListCastFunction<T> castFn) → void
serialize<T>(T item) → String?
serializeToMap<T>(T? item) → Map<String, dynamic>?